@@ -13,8 +13,3 @@ then
     rm /etc/profile.d/bindkey.tcsh
 fi
 
-if [ -f /etc/profile.d/complete.tcsh ] && cmp -s /etc/defaults/etc/profile.d/complete.tcsh /etc/profile.d/complete.tcsh
-then
-    rm /etc/profile.d/complete.tcsh
-fi
-
